@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::Author::KENTNL;
 BEGIN {
-  $Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '1.0.4';
+  $Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '1.0.5';
 }
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
@@ -135,7 +135,7 @@ sub bundle_config {
     ],
     [ 'GatherDir'  => { include_dotfiles => 1 } ],
     [ 'MetaConfig' => {} ],
-    [ 'PruneCruft' => { except => '^.perltidyrc' } ],
+    [ 'PruneCruft' => { except           => '^.perltidyrc' } ],
     _only_git( $arg, [ 'GithubMeta' => {} ] ),
     [ 'License'               => {} ],
     [ 'PkgVersion'            => {} ],
@@ -147,24 +147,28 @@ sub bundle_config {
     [ 'ReadmeFromPod'         => {} ],
     [ 'ManifestSkip'          => {} ],
     [ 'Manifest'              => {} ],
-    [ 'AutoPrereqs'           => {} ],
+    [ 'AutoPrereqs'           => { skip => _defined_or( $arg, auto_prereqs_skip => q{}, 1 ) } ],
     [
-      'Prereqs' =>
-        { -name => 'BundleDevelNeeds', -phase => 'develop', -type => 'requires', 'Dist::Zilla::PluginBundle::Author::KENTNL::Lite' => 0 }
+      'Prereqs' => {
+        -name                                             => 'BundleDevelNeeds',
+        -phase                                            => 'develop',
+        -type                                             => 'requires',
+        'Dist::Zilla::PluginBundle::Author::KENTNL::Lite' => 0
+      }
     ],
     [
       'Prereqs' => {
-        -name                                     => 'BundleDevelRecommends',
-        -phase                                    => 'develop',
-        -type                                     => 'recommends',
+        -name                                             => 'BundleDevelRecommends',
+        -phase                                            => 'develop',
+        -type                                             => 'recommends',
         'Dist::Zilla::PluginBundle::Author::KENTNL::Lite' => 0.01009803
       }
     ],
     [
       'Prereqs' => {
-        -name                               => 'BundleDevelSuggests',
-        -phase                              => 'develop',
-        -type                               => 'suggests',
+        -name                                       => 'BundleDevelSuggests',
+        -phase                                      => 'develop',
+        -type                                       => 'suggests',
         'Dist::Zilla::PluginBundle::Author::KENTNL' => '1.0.0',
       }
     ],
@@ -217,7 +221,7 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 1.0.4
+version 1.0.5
 
 =head1 SYNOPSIS
 
